#!/bin/bash
# packager           : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# homepage           : http://www.alsa-project.org/main/index.php/Main_Page
# source location    :
# ftp://ftp.alsa-project.org/pub/firmware/alsa-firmware-1.0.25.tar.bz2
# last revised       : 04.04.2012
# dep                : 

softname='alsa-firmware'
softversion='1.0.25'
packageversion='72.1'

arch='i486'
cpu='i686'

# log ;)
(

# parameters needed for the build process
buildir=$(pwd)
srcpkg="$buildir/$softname-$softversion.tar.bz2"
src="$buildir/$softname-$softversion"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=ftp://ftp.alsa-project.org/pub/firmware/$softname-$softversion.tar.bz2

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc
             |-----handy-ruler------------------------------------------------------|
alsa-firmware: alsa-firmware - ALSA firmware package
alsa-firmware:
alsa-firmware: Advanced Linux Sound Architecture firmware
alsa-firmware: Firmware binaries for some soundcards that need it
alsa-firmware: 
alsa-firmware: 
alsa-firmware: 
alsa-firmware: 
alsa-firmware: 
alsa-firmware:
alsa-firmware: 
EOF

# check if source is present
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code
cd $buildir
tar xvf $srcpkg
cd $src

# build
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"

sed -i s#'multisound/Makefile \\'## configure.in
sed -i s#multisound## Makefile.am
  
./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make
make install DESTDIR=$dest

rm -rf $dest/lib/firmware/turtlebeach
rm -rf $dest/lib/firmware/{korg,yamaha,ess}
rm -rf $dest/usr/bin

mv $dest/usr/share/alsa/firmware/mixartloader/miXart.conf $dest/usr/share/alsa/firmware/mixartloader/miXart.conf.new
mv $dest/usr/share/alsa/firmware/pcxhrloader/pcxhr.conf $dest/usr/share/alsa/firmware/pcxhrloader/pcxhr.conf.new
mv $dest/usr/share/alsa/firmware/pcxhrloader/pcxhr0.conf $dest/usr/share/alsa/firmware/pcxhrloader/pcxhr0.conf.new
mv $dest/usr/share/alsa/firmware/pcxhrloader/pcxhr1.conf $dest/usr/share/alsa/firmware/pcxhrloader/pcxhr1.conf.new
mv $dest/usr/share/alsa/firmware/pcxhrloader/pcxhr2.conf $dest/usr/share/alsa/firmware/pcxhrloader/pcxhr2.conf.new
mv $dest/usr/share/alsa/firmware/pcxhrloader/pcxhr3.conf $dest/usr/share/alsa/firmware/pcxhrloader/pcxhr3.conf.new
mv $dest/usr/share/alsa/firmware/pcxhrloader/pcxhr4.conf $dest/usr/share/alsa/firmware/pcxhrloader/pcxhr4.conf.new
mv $dest/usr/share/alsa/firmware/pcxhrloader/pcxhr5.conf $dest/usr/share/alsa/firmware/pcxhrloader/pcxhr4.conf.new
mv $dest/usr/share/alsa/firmware/usx2yloader/us122.conf $dest/usr/share/alsa/firmware/usx2yloader/us122.conf.new
mv $dest/usr/share/alsa/firmware/usx2yloader/us224.conf $dest/usr/share/alsa/firmware/usx2yloader/us224.conf.new
mv $dest/usr/share/alsa/firmware/usx2yloader/us428.conf $dest/usr/share/alsa/firmware/usx2yloader/us428.conf.new
mv $dest/usr/share/alsa/firmware/vxloader/vx222.conf $dest/usr/share/alsa/firmware/vxloader/vx222.conf.new
mv $dest/usr/share/alsa/firmware/vxloader/vxboard.conf $dest/usr/share/alsa/firmware/vxloader/vxboard.conf.new
mv $dest/usr/share/alsa/firmware/vxloader/vxpocket.conf $dest/usr/share/alsa/firmware/vxloader/vxpocket.conf.new
mv $dest/usr/share/alsa/firmware/vxloader/vxp440.conf $dest/usr/share/alsa/firmware/vxloader/vxp440.conf.new

# replace the new file if needed
cat << "EOF" > $dest/install/doinst.sh
config() {
  NEW="$1"
  OLD="`dirname $NEW`/`basename $NEW .new`"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "`cat $OLD | md5sum`" = "`cat $NEW | md5sum`" ]; then # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}
config usr/share/alsa/firmware/mixartloader/miXart.conf.new
config usr/share/alsa/firmware/pcxhrloader/pcxhr.conf.new
config usr/share/alsa/firmware/pcxhrloader/pcxhr0.conf.new
config usr/share/alsa/firmware/pcxhrloader/pcxhr1.conf.new
config usr/share/alsa/firmware/pcxhrloader/pcxhr2.conf.new
config usr/share/alsa/firmware/pcxhrloader/pcxhr3.conf.new
config usr/share/alsa/firmware/pcxhrloader/pcxhr4.conf.new
config usr/share/alsa/firmware/pcxhrloader/pcxhr5.conf.new
config usr/share/alsa/firmware/usx2yloader/us122.conf.new
config usr/share/alsa/firmware/usx2yloader/us224.conf.new
config usr/share/alsa/firmware/usx2yloader/us428.conf.new
config usr/share/alsa/firmware/vxloader/vx222.conf.new
config usr/share/alsa/firmware/vxloader/vxboard.conf.new
config usr/share/alsa/firmware/vxloader/vxpocket.conf.new
config usr/share/alsa/firmware/vxloader/vxp440.conf.new
EOF

# add 'default' files
cd $src
mkdir -p $dest/usr/doc/$softname-$softversion
cp -a \
   README COPYING\
   $dest/usr/doc/$softname-$softversion
cp $src/hdsploader/README $dest/usr/doc/$softname-$softversion/README.hdsploader
cp $src/mixartloader/README $dest/usr/doc/$softname-$softversion/README.mixartloader
cp $src/pcxhrloader/README $dest/usr/doc/$softname-$softversion/README.pcxhrloader
cp $src/usx2yloader/README $dest/usr/doc/$softname-$softversion/README.usx2yloader
cp $src/vxloader/README $dest/usr/doc/$softname-$softversion/README.vxloader

        
# strip executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# compress man pages
( cd $dest/usr/man
  find . -name "*.?" | xargs gzip -9
)

# ZenBuild
cp $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion

# set target permissions
chown -R root:root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# computes the md5sum signature for the package
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "" > $package.dep

# src file
echo http://zenwalk.pinguix.com/user-accounts/bip/ISO/a/alsa-firmware/build-alsa-firmware.sh > $package.src
echo $source >> $package.src

# erase
rm -rf $src
rm -rf $dest

# log ;)
) 2>&1 | tee "$softname-$softversion-build.log"
